pub enum ValidationCode {
EmptyAppLabel,
EmptyName,
DuplicateMigration,
DuplicateMigrationNumber,
SelfDependency,
MissingDependency,
DependencyCycle,
DuplicateAppliedRecord,
UnknownAppliedMigration,
AppliedDependencyMissing,
}Expand description
Stable validation error code for machine-readable assertions.
Variants
EmptyAppLabel
Migration app label is empty.
EmptyName
Migration name is empty.
DuplicateMigration
More than one loaded migration has the same app/name identity.
DuplicateMigrationNumber
More than one migration in an app uses the same numeric prefix.
SelfDependency
A migration depends on itself.
MissingDependency
A dependency target is not present in the loaded graph.
DependencyCycle
A dependency cycle was detected.
DuplicateAppliedRecord
More than one applied record has the same app/name identity.
UnknownAppliedMigration
Applied state references a migration not present in the loaded graph.
AppliedDependencyMissing
An applied migration has an unapplied dependency.