pub struct MigrationValidationError {
pub code: ValidationCode,
pub app_label: String,
pub name: String,
pub message: String,
}Expand description
Structured migration validation error.
Fields
code: ValidationCodeStable validation code.
app_label: StringApp label associated with the failing migration when available.
name: StringMigration name associated with the failing migration when available.
message: StringHuman-readable validation message.