pub struct MigrationExecutorInfo {
pub ip: Option<String>,
pub mac: Option<String>,
}Expand description
Best-effort executor identity stored with migration run-log rows.
Fields
ip: Option<String>Best-effort local IP address of the process that executed the migration.
mac: Option<String>Best-effort MAC address of the process that executed the migration.